@@ -300,12 +300,12 @@ impl Client {
 mod tests {
     use crate::client::client_api::blob_apis::Blob;
     use crate::client::utils::test_utils::create_test_client;
+    use crate::client::BlobAddress;
     use crate::types::{utils::random_bytes, Keypair};
     use crate::url::Scope;
     use bytes::Bytes;
     use eyre::Result;
     use futures::future::join_all;
-    use itertools::Itertools;
     use rand::rngs::OsRng;
     use tokio::time::Instant;
 
@@ -377,54 +377,34 @@ mod tests {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn seek_in_data() -> Result<()> {
-        let tasks = (1..5)
-            .map(|i| {
-                tokio::task::spawn(async move {
-                    let size = i * MIN_BLOB_SIZE;
-                    let tasks = (2..5).map(|divisor| {
-                        tokio::task::spawn(async move {
-                            let len = size / divisor;
-                            let blob = Blob::new(random_bytes(size))?;
+        let client = create_test_client().await?;
+        for i in 1..5 {
+            let size = i * MIN_BLOB_SIZE;
+            for divisor in 2..5 {
+                let len = size / divisor;
+                let blob = Blob::new(random_bytes(size))?;
 
-                            // Read first part
-                            let read_data_1 = {
-                                let pos = 0;
-                                seek_for_test(blob.clone(), pos, len).await?
-                            };
+                let address = store_for_seek(blob.clone(), &client).await?;
 
-                            // Read second part
-                            let read_data_2 = {
-                                let pos = len;
-                                seek_for_test(blob.clone(), pos, len).await?
-                            };
+                // Read first part
+                let read_data_1 = {
+                    let pos = 0;
+                    get_for_seek(blob.clone(), address, pos, len, &client).await?
+                };
 
-                            // Join parts
-                            let read_data: Bytes = [read_data_1, read_data_2]
-                                .iter()
-                                .flat_map(|bytes| bytes.clone())
-                                .collect();
+                // Read second part
+                let read_data_2 = {
+                    let pos = len;
+                    get_for_seek(blob.clone(), address, pos, len, &client).await?
+                };
 
-                            compare(blob.bytes().slice(0..(2 * len)), read_data)
-                        })
-                    });
+                // Join parts
+                let read_data: Bytes = [read_data_1, read_data_2]
+                    .iter()
+                    .flat_map(|bytes| bytes.clone())
+                    .collect();
 
-                    join_all(tasks).await
-                })
-            })
-            .collect_vec();
-
-        let r_1_vec = join_all(tasks).await;
-        for r_1 in r_1_vec {
-            match r_1 {
-                Ok(r_2_vec) => {
-                    for r_2 in r_2_vec {
-                        match r_2 {
-                            Ok(r_3) => r_3?,
-                            Err(e) => eyre::bail!(e),
-                        }
-                    }
-                }
-                Err(e) => eyre::bail!(e),
+                compare(blob.bytes().slice(0..(2 * len)), read_data)?;
             }
         }
 
@@ -544,18 +524,26 @@ mod tests {
         Ok(())
     }
 
-    async fn seek_for_test(blob: Blob, pos: usize, len: usize) -> Result<Bytes> {
-        let client = create_test_client().await?;
+    async fn store_for_seek(blob: Blob, client: &super::Client) -> Result<BlobAddress> {
         let address = client.upload_blob(blob.clone(), Scope::Public).await?;
-
         // the larger the file, the longer we have to wait before we start querying
-        let delay = tokio::time::Duration::from_secs(usize::max(1, len / DELAY_DIVIDER) as u64);
+        let delay = tokio::time::Duration::from_secs(usize::max(
+            1,
+            blob.bytes().len() / DELAY_DIVIDER,
+        ) as u64);
         tokio::time::sleep(delay).await;
+        Ok(address)
+    }
 
+    async fn get_for_seek(
+        blob: Blob,
+        address: BlobAddress,
+        pos: usize,
+        len: usize,
+        client: &super::Client,
+    ) -> Result<Bytes> {
         let read_data = client.read_from(address, pos, len).await?;
-
         compare(blob.bytes().slice(pos..(pos + len)), read_data.clone())?;
-
         Ok(read_data)
     }
 
