@@ -229,14 +229,26 @@ impl Section {
         self.authority_provider().contains_elder(name)
     }
 
-    /// Generate a new section info(s) based on the current set of members.
+    /// Generate a new section info(s) based on the current set of members,
+    /// excluding any member matching a name in the provided `excluded_names` set.
     /// Returns a set of candidate SectionAuthorityProviders.
-    pub(super) fn promote_and_demote_elders(&self, our_name: &XorName) -> Vec<ElderCandidates> {
-        if let Some((our_elder_candidates, other_elder_candidates)) = self.try_split(our_name) {
+    pub(super) fn promote_and_demote_elders(
+        &self,
+        our_name: &XorName,
+        excluded_names: &BTreeSet<XorName>,
+    ) -> Vec<ElderCandidates> {
+        if let Some((our_elder_candidates, other_elder_candidates)) =
+            self.try_split(our_name, excluded_names)
+        {
             return vec![our_elder_candidates, other_elder_candidates];
         }
 
-        let expected_peers = self.elder_candidates(ELDER_SIZE);
+        // Candidates for elders out of all the nodes in the section, even out of the
+        // relocating nodes if there would not be enough instead.
+        let expected_peers =
+            self.members
+                .elder_candidates(ELDER_SIZE, self.authority_provider(), excluded_names);
+
         let expected_names: BTreeSet<_> = expected_peers.iter().map(Peer::name).cloned().collect();
         let current_names: BTreeSet<_> = self.authority_provider().names();
 
@@ -306,6 +318,7 @@ impl Section {
     pub(super) fn try_split(
         &self,
         our_name: &XorName,
+        excluded_names: &BTreeSet<XorName>,
     ) -> Option<(ElderCandidates, ElderCandidates)> {
         let next_bit_index = if let Ok(index) = self.prefix().bit_count().try_into() {
             index
@@ -319,6 +332,7 @@ impl Section {
         let (our_new_size, sibling_new_size) = self
             .members
             .mature()
+            .filter(|peer| !excluded_names.contains(peer.name()))
             .map(|peer| peer.name().bit(next_bit_index) == next_bit)
             .fold((0, 0), |(ours, siblings), is_our_prefix| {
                 if is_our_prefix {
@@ -340,11 +354,13 @@ impl Section {
             &our_prefix,
             ELDER_SIZE,
             self.authority_provider(),
+            excluded_names,
         );
         let other_elders = self.members.elder_candidates_matching_prefix(
             &other_prefix,
             ELDER_SIZE,
             self.authority_provider(),
+            excluded_names,
         );
 
         let our_elder_candidates = ElderCandidates::new(our_elders, our_prefix);
@@ -352,13 +368,6 @@ impl Section {
 
         Some((our_elder_candidates, other_elder_candidates))
     }
-
-    // Returns the candidates for elders out of all the nodes in the section, even out of the
-    // relocating nodes if there would not be enough instead.
-    pub(super) fn elder_candidates(&self, elder_size: usize) -> Vec<Peer> {
-        self.members
-            .elder_candidates(elder_size, self.authority_provider())
-    }
 }
 
 // Create `SectionAuthorityProvider` for the first node.
