@@ -205,7 +205,7 @@ mod tests {
         },
         utils, Error, Keypair, Result,
     };
-    use crate::client::BlobAddress;
+    use crate::client::{BlobAddress, BytesAddress};
     use crate::url::Url;
     use eyre::eyre;
     use proptest::prelude::*;
@@ -1162,8 +1162,8 @@ mod tests {
 
     fn random_url() -> Result<Url> {
         use crate::url::*;
-        let url = Url::encode_blob(
-            BlobAddress::Public(XorName::random()),
+        let url = Url::encode_bytes(
+            BytesAddress::Blob(BlobAddress::Public(XorName::random())),
             ContentType::Raw,
             XorUrlBase::Base32z,
         )
